utils

package
v0.0.0-...-389ea72 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 22, 2019 License: GPL-3.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func EvalStringWithUUID

func EvalStringWithUUID(uuid string, str string) (string, error)

EvalStringWithUUID uses shell evaluation to evaluate an output

func GetFileContent

func GetFileContent(clusterid string, path string) ([]string, error)

GetFileContent reads a file content while evaluating its output

func IsCommandMissingError

func IsCommandMissingError(err error) bool

IsCommandMissingError checks if error is a CommandMissingError

func NewCommandMissingError

func NewCommandMissingError() error

NewCommandMissingError creates a new error which is causes due to command missing

func PrintIfDebug

func PrintIfDebug(debug bool, title string, out string)

PrintIfDebug prints if debug flag is set

func ReadYamlFile

func ReadYamlFile(o interface{}, filename string) error

ReadYamlFile reads the contents of yaml file and returns the contents

func RunCommandWithUUID

func RunCommandWithUUID(uuid string, command string) (string, error)

RunCommandWithUUID runs a command with uuid

func WriteFile

func WriteFile(filepath string, data []byte) error

WriteFile writes data to a file

Types

This section is empty.

Jump to