Documentation
¶
Index ¶
- func EvalStringWithUUID(uuid string, str string) (string, error)
- func GetFileContent(clusterid string, path string) ([]string, error)
- func IsCommandMissingError(err error) bool
- func NewCommandMissingError() error
- func PrintIfDebug(debug bool, title string, out string)
- func ReadYamlFile(o interface{}, filename string) error
- func RunCommandWithUUID(uuid string, command string) (string, error)
- func WriteFile(filepath string, data []byte) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EvalStringWithUUID ¶
EvalStringWithUUID uses shell evaluation to evaluate an output
func GetFileContent ¶
GetFileContent reads a file content while evaluating its output
func IsCommandMissingError ¶
IsCommandMissingError checks if error is a CommandMissingError
func NewCommandMissingError ¶
func NewCommandMissingError() error
NewCommandMissingError creates a new error which is causes due to command missing
func PrintIfDebug ¶
PrintIfDebug prints if debug flag is set
func ReadYamlFile ¶
ReadYamlFile reads the contents of yaml file and returns the contents
func RunCommandWithUUID ¶
RunCommandWithUUID runs a command with uuid
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.